@@ -1,14 +1,13 @@
 from __future__ import annotations
 
-import copy
 import re
+import warnings
 
 from contextlib import contextmanager
-from pathlib import Path
 from typing import TYPE_CHECKING
-from typing import Collection
-from typing import Iterable
-from typing import Iterator
+from typing import ClassVar
+from typing import Mapping
+from typing import Sequence
 from typing import TypeVar
 
 from poetry.core.constraints.version import parse_constraint
@@ -21,6 +20,11 @@ from poetry.core.version.markers import parse_marker
 
 
 if TYPE_CHECKING:
+    from collections.abc import Collection
+    from collections.abc import Iterable
+    from collections.abc import Iterator
+    from pathlib import Path
+
     from packaging.utils import NormalizedName
 
     from poetry.core.constraints.version import Version
@@ -32,11 +36,13 @@ if TYPE_CHECKING:
 
     T = TypeVar("T", bound="Package")
 
-AUTHOR_REGEX = re.compile(r"(?u)^(?P<name>[- .,\w\d'’\"():&]+)(?: <(?P<email>.+?)>)?$")
+AUTHOR_REGEX = re.compile(
+    r"(?u)^(?P<name>[- .,\w\d'’\"():&]+)(?: <(?P<email>.+?)>)?$"  # noqa: RUF001
+)
 
 
 class Package(PackageSpecification):
-    AVAILABLE_PYTHONS = {
+    AVAILABLE_PYTHONS: ClassVar[set[str]] = {
         "2",
         "2.7",
         "3",
@@ -48,6 +54,7 @@ class Package(PackageSpecification):
         "3.9",
         "3.10",
         "3.11",
+        "3.12",
     }
 
     def __init__(
@@ -69,6 +76,14 @@ class Package(PackageSpecification):
         """
         from poetry.core.version.markers import AnyMarker
 
+        if pretty_version is not None:
+            warnings.warn(
+                "The `pretty_version` parameter is deprecated and will be removed"
+                " in a future release.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+
         super().__init__(
             name,
             source_type=source_type,
@@ -79,36 +94,38 @@ class Package(PackageSpecification):
             features=features,
         )
 
-        self._set_version(version, pretty_version)
+        # Attributes must be immutable for clone() to be safe!
+        # (For performance reasons, clone only creates a copy instead of a deep copy).
+
+        self._set_version(version)
 
         self.description = ""
 
-        self._authors: list[str] = []
-        self._maintainers: list[str] = []
+        self.authors: Sequence[str] = []
+        self.maintainers: Sequence[str] = []
 
         self.homepage: str | None = None
         self.repository_url: str | None = None
         self.documentation_url: str | None = None
-        self.keywords: list[str] = []
+        self.keywords: Sequence[str] = []
         self._license: License | None = None
         self.readmes: tuple[Path, ...] = ()
 
-        self.extras: dict[NormalizedName, list[Dependency]] = {}
+        self.extras: Mapping[NormalizedName, Sequence[Dependency]] = {}
 
-        self._dependency_groups: dict[str, DependencyGroup] = {}
+        self._dependency_groups: Mapping[str, DependencyGroup] = {}
 
-        # For compatibility with previous version, we keep the category
-        self.category = "main"
-        self.files: list[dict[str, str]] = []
+        # Category is heading towards deprecation.
+        self._category = "main"
+        self.files: Sequence[Mapping[str, str]] = []
         self.optional = False
 
-        self.classifiers: list[str] = []
+        self.classifiers: Sequence[str] = []
 
         self._python_versions = "*"
         self._python_constraint = parse_constraint("*")
         self._python_marker: BaseMarker = AnyMarker()
 
-        self.platform = None
         self.marker: BaseMarker = AnyMarker()
 
         self.root_dir: Path | None = None
@@ -131,7 +148,7 @@ class Package(PackageSpecification):
 
     @property
     def pretty_version(self) -> str:
-        return self._pretty_version
+        return self._version.text
 
     @property
     def unique_name(self) -> str:
@@ -146,27 +163,23 @@ class Package(PackageSpecification):
 
     @property
     def full_pretty_version(self) -> str:
-        if self.source_type in ["file", "directory", "url"]:
-            return f"{self._pretty_version} {self.source_url}"
+        if self.source_type in ("file", "directory", "url"):
+            return f"{self.pretty_version} {self.source_url}"
 
-        if self.source_type not in ["hg", "git"]:
-            return self._pretty_version
+        if self.source_type not in ("hg", "git"):
+            return self.pretty_version
 
         ref: str | None
         if self.source_resolved_reference and len(self.source_resolved_reference) == 40:
             ref = self.source_resolved_reference[0:7]
-            return f"{self._pretty_version} {ref}"
+            return f"{self.pretty_version} {ref}"
 
         # if source reference is a sha1 hash -- truncate
         if self.source_reference and len(self.source_reference) == 40:
-            return f"{self._pretty_version} {self.source_reference[0:7]}"
+            return f"{self.pretty_version} {self.source_reference[0:7]}"
 
         ref = self._source_resolved_reference or self._source_reference
-        return f"{self._pretty_version} {ref}"
-
-    @property
-    def authors(self) -> list[str]:
-        return self._authors
+        return f"{self.pretty_version} {ref}"
 
     @property
     def author_name(self) -> str | None:
@@ -176,10 +189,6 @@ class Package(PackageSpecification):
     def author_email(self) -> str | None:
         return self._get_author()["email"]
 
-    @property
-    def maintainers(self) -> list[str]:
-        return self._maintainers
-
     @property
     def maintainer_name(self) -> str | None:
         return self._get_maintainer()["name"]
@@ -211,9 +220,7 @@ class Package(PackageSpecification):
             for dependency in group.dependencies
         ]
 
-    def _set_version(
-        self, version: str | Version, pretty_version: str | None = None
-    ) -> None:
+    def _set_version(self, version: str | Version) -> None:
         from poetry.core.constraints.version import Version
 
         if not isinstance(version, Version):
@@ -225,13 +232,12 @@ class Package(PackageSpecification):
                 )
 
         self._version = version
-        self._pretty_version = pretty_version or version.text
 
     def _get_author(self) -> dict[str, str | None]:
-        if not self._authors:
+        if not self.authors:
             return {"name": None, "email": None}
 
-        m = AUTHOR_REGEX.match(self._authors[0])
+        m = AUTHOR_REGEX.match(self.authors[0])
 
         if m is None:
             raise ValueError(
@@ -245,10 +251,10 @@ class Package(PackageSpecification):
         return {"name": name, "email": email}
 
     def _get_maintainer(self) -> dict[str, str | None]:
-        if not self._maintainers:
+        if not self.maintainers:
             return {"name": None, "email": None}
 
-        m = AUTHOR_REGEX.match(self._maintainers[0])
+        m = AUTHOR_REGEX.match(self.maintainers[0])
 
         if m is None:
             raise ValueError(
@@ -304,7 +310,7 @@ class Package(PackageSpecification):
     def all_classifiers(self) -> list[str]:
         from poetry.core.constraints.version import Version
 
-        classifiers = copy.copy(self.classifiers)
+        classifiers = list(self.classifiers)
 
         # Automatically set python classifiers
         if self.python_versions == "*":
@@ -338,7 +344,7 @@ class Package(PackageSpecification):
         # it like this so that 3.10 is sorted after 3.9.
         sorted_classifiers = []
         python_classifiers_inserted = False
-        for classifier in sorted(set(classifiers)):
+        for classifier in sorted(set(classifiers) - set(python_classifiers)):
             if (
                 not python_classifiers_inserted
                 and classifier > python_classifier_prefix
@@ -368,24 +374,40 @@ class Package(PackageSpecification):
         return urls
 
     @property
-    def readme(self) -> Path | None:
-        import warnings
-
+    def category(self) -> str:
         warnings.warn(
-            "`readme` is deprecated: you are getting only the first readme file. Please"
-            " use the plural form `readmes`.",
+            "`category` is deprecated and will be removed in a future release.",
             DeprecationWarning,
+            stacklevel=2,
+        )
+        return self._category
+
+    @category.setter
+    def category(self, category: str) -> None:
+        warnings.warn(
+            "Setting `category` is deprecated and will be removed in a future release.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        self._category = category
+
+    @property
+    def readme(self) -> Path | None:
+        warnings.warn(
+            "`readme` is deprecated: you are getting only the first readme file."
+            " Please use the plural form `readmes`.",
+            DeprecationWarning,
+            stacklevel=2,
         )
         return next(iter(self.readmes), None)
 
     @readme.setter
     def readme(self, path: Path) -> None:
-        import warnings
-
         warnings.warn(
             "`readme` is deprecated. Please assign a tuple to the plural form"
             " `readmes`.",
             DeprecationWarning,
+            stacklevel=2,
         )
         self.readmes = (path,)
 
@@ -413,7 +435,9 @@ class Package(PackageSpecification):
         }
 
     def add_dependency_group(self, group: DependencyGroup) -> None:
-        self._dependency_groups[group.name] = group
+        groups = dict(self._dependency_groups)
+        groups[group.name] = group
+        self._dependency_groups = groups
 
     def has_dependency_group(self, name: str) -> bool:
         return name in self._dependency_groups
@@ -443,11 +467,14 @@ class Package(PackageSpecification):
         """
         Returns a clone of the package with the given dependency groups excluded.
         """
-        package = self.clone()
+        updated_groups = {
+            group_name: group
+            for group_name, group in self._dependency_groups.items()
+            if group_name not in groups
+        }
 
-        for group_name in groups:
-            if group_name in package._dependency_groups:
-                del package._dependency_groups[group_name]
+        package = self.clone()
+        package._dependency_groups = updated_groups
 
         return package
 
@@ -455,11 +482,13 @@ class Package(PackageSpecification):
         """
         Returns a clone of the package without optional dependency groups.
         """
+        updated_groups = {
+            group_name: group
+            for group_name, group in self._dependency_groups.items()
+            if not group.is_optional()
+        }
         package = self.clone()
-
-        for group_name, group in self._dependency_groups.items():
-            if group.is_optional():
-                del package._dependency_groups[group_name]
+        package._dependency_groups = updated_groups
 
         return package
 
@@ -474,11 +503,13 @@ class Package(PackageSpecification):
 
         If `only` is set to True, then only the given groups will be selected.
         """
+        updated_groups = {
+            group_name: group
+            for group_name, group in self._dependency_groups.items()
+            if group_name in groups or not only and not group.is_optional()
+        }
         package = self.clone()
-
-        for group_name, group in self._dependency_groups.items():
-            if (only or group.is_optional()) and group_name not in groups:
-                del package._dependency_groups[group_name]
+        package._dependency_groups = updated_groups
 
         return package
 
@@ -508,6 +539,7 @@ class Package(PackageSpecification):
             dep = FileDependency(
                 self._name,
                 Path(self._source_url),
+                directory=self.source_subdirectory,
                 groups=list(self._dependency_groups.keys()),
                 optional=self.optional,
                 base=self.root_dir,
@@ -576,7 +608,7 @@ class Package(PackageSpecification):
         if not dependency.constraint.allows(self.version):
             return False
 
-        if not ignore_source_type and not self.source_satisfies(dependency):
+        if not (ignore_source_type or self.source_satisfies(dependency)):
             return False
 
         return True
@@ -625,21 +657,21 @@ class Package(PackageSpecification):
         args = [repr(self._name), repr(self._version.text)]
 
         if self._features:
-            args.append(f"features={repr(self._features)}")
+            args.append(f"features={self._features!r}")
 
         if self._source_type:
-            args.append(f"source_type={repr(self._source_type)}")
-            args.append(f"source_url={repr(self._source_url)}")
+            args.append(f"source_type={self._source_type!r}")
+            args.append(f"source_url={self._source_url!r}")
 
             if self._source_reference:
-                args.append(f"source_reference={repr(self._source_reference)}")
+                args.append(f"source_reference={self._source_reference!r}")
 
             if self._source_resolved_reference:
                 args.append(
-                    f"source_resolved_reference={repr(self._source_resolved_reference)}"
+                    f"source_resolved_reference={self._source_resolved_reference!r}"
                 )
             if self._source_subdirectory:
-                args.append(f"source_subdirectory={repr(self._source_subdirectory)}")
+                args.append(f"source_subdirectory={self._source_subdirectory!r}")
 
         args_str = ", ".join(args)
         return f"Package({args_str})"
