@@ -18,7 +18,8 @@ import pytest
 
 from poetry.core import __version__
 from poetry.core.factory import Factory
-from poetry.core.masonry.builder import Builder
+from poetry.core.masonry.builders.sdist import SdistBuilder
+from poetry.core.masonry.builders.wheel import WheelBuilder
 from tests.masonry.builders.test_wheel import WHEEL_TAG_REGEX
 
 
@@ -56,8 +57,9 @@ def clear_samples_dist() -> None:
 )
 def test_wheel_c_extension(project: str, exptected_c_dir: str) -> None:
     module_path = fixtures_dir / project
-    builder = Builder(Factory().create_poetry(module_path))
-    builder.build(fmt="all")
+    poetry = Factory().create_poetry(module_path)
+    SdistBuilder(poetry).build()
+    WheelBuilder(poetry).build()
 
     sdist = fixtures_dir / project / "dist" / "extended-0.1.tar.gz"
     assert sdist.exists()
@@ -110,8 +112,10 @@ def test_complete(no_vcs: bool) -> None:
         shutil.copytree(module_path.as_posix(), temporary_dir.as_posix())
         module_path = temporary_dir
 
-    builder = Builder(Factory().create_poetry(module_path))
-    builder.build(fmt="all")
+    poetry = Factory().create_poetry(module_path)
+    with pytest.warns(DeprecationWarning, match=".* script .* extra"):
+        SdistBuilder(poetry).build()
+        WheelBuilder(poetry).build()
 
     whl = module_path / "dist" / "my_package-1.2.3-py3-none-any.whl"
 
@@ -133,6 +137,9 @@ def test_complete(no_vcs: bool) -> None:
                 "my_package-1.2.3.dist-info/LICENSE",
                 "my_package-1.2.3.dist-info/METADATA",
                 "my_package-1.2.3.dist-info/WHEEL",
+                "my_package-1.2.3.dist-info/COPYING",
+                "my_package-1.2.3.dist-info/LICENCE",
+                "my_package-1.2.3.dist-info/AUTHORS",
             ],
             key=lambda x: Path(x),
         ),
@@ -148,24 +155,32 @@ def test_complete(no_vcs: bool) -> None:
 
         entry_points = zipf.read("my_package-1.2.3.dist-info/entry_points.txt")
 
-        assert entry_points.decode() == """\
+        assert (
+            entry_points.decode()
+            == """\
 [console_scripts]
 extra-script=my_package.extra:main[time]
 my-2nd-script=my_package:main2
 my-script=my_package:main
 
 """
+        )
         wheel_data = zipf.read("my_package-1.2.3.dist-info/WHEEL").decode()
 
-        assert wheel_data == f"""\
+        assert (
+            wheel_data
+            == f"""\
 Wheel-Version: 1.0
 Generator: poetry-core {__version__}
 Root-Is-Purelib: true
 Tag: py3-none-any
 """
+        )
         wheel_data = zipf.read("my_package-1.2.3.dist-info/METADATA").decode()
 
-        assert wheel_data == """\
+        assert (
+            wheel_data
+            == """\
 Metadata-Version: 2.1
 Name: my-package
 Version: 1.2.3
@@ -186,6 +201,7 @@ Classifier: Programming Language :: Python :: 3.8
 Classifier: Programming Language :: Python :: 3.9
 Classifier: Programming Language :: Python :: 3.10
 Classifier: Programming Language :: Python :: 3.11
+Classifier: Programming Language :: Python :: 3.12
 Classifier: Topic :: Software Development :: Build Tools
 Classifier: Topic :: Software Development :: Libraries :: Python Modules
 Provides-Extra: time
@@ -202,6 +218,7 @@ My Package
 ==========
 
 """
+        )
         actual_records = zipf.read("my_package-1.2.3.dist-info/RECORD").decode()
 
         # The SHA hashes vary per operating systems.
@@ -213,8 +230,9 @@ My Package
 
 def test_module_src() -> None:
     module_path = fixtures_dir / "source_file"
-    builder = Builder(Factory().create_poetry(module_path))
-    builder.build(fmt="all")
+    poetry = Factory().create_poetry(module_path)
+    SdistBuilder(poetry).build()
+    WheelBuilder(poetry).build()
 
     sdist = module_path / "dist" / "module_src-0.1.tar.gz"
 
@@ -233,8 +251,9 @@ def test_module_src() -> None:
 
 def test_package_src() -> None:
     module_path = fixtures_dir / "source_package"
-    builder = Builder(Factory().create_poetry(module_path))
-    builder.build(fmt="all")
+    poetry = Factory().create_poetry(module_path)
+    SdistBuilder(poetry).build()
+    WheelBuilder(poetry).build()
 
     sdist = module_path / "dist" / "package_src-0.1.tar.gz"
 
@@ -254,8 +273,9 @@ def test_package_src() -> None:
 
 def test_split_source() -> None:
     module_path = fixtures_dir / "split_source"
-    builder = Builder(Factory().create_poetry(module_path))
-    builder.build(fmt="all")
+    poetry = Factory().create_poetry(module_path)
+    SdistBuilder(poetry).build()
+    WheelBuilder(poetry).build()
 
     sdist = module_path / "dist" / "split_source-0.1.tar.gz"
 
@@ -296,8 +316,10 @@ def test_package_with_include(mocker: MockerFixture) -> None:
             / "vcs_excluded.txt"
         ),
     ]
-    builder = Builder(Factory().create_poetry(module_path))
-    builder.build(fmt="all")
+
+    poetry = Factory().create_poetry(module_path)
+    SdistBuilder(poetry).build()
+    WheelBuilder(poetry).build()
 
     sdist = fixtures_dir / "with-include" / "dist" / "with_include-1.2.3.tar.gz"
 
@@ -320,6 +342,7 @@ def test_package_with_include(mocker: MockerFixture) -> None:
         assert "with_include-1.2.3/PKG-INFO" in names
         assert "with_include-1.2.3/for_wheel_only/__init__.py" not in names
         assert "with_include-1.2.3/src/src_package/__init__.py" in names
+        assert "with_include-1.2.3/etc/from_to/__init__.py" in names
 
     whl = module_path / "dist" / "with_include-1.2.3-py3-none-any.whl"
 
@@ -339,12 +362,15 @@ def test_package_with_include(mocker: MockerFixture) -> None:
         assert "package_with_include/__init__.py" in names
         assert "tests/__init__.py" not in names
         assert "src_package/__init__.py" in names
+        assert "target_from_to/from_to/__init__.py" in names
+        assert "target_module/my_module_to.py" in names
 
 
 def test_respect_format_for_explicit_included_files() -> None:
     module_path = fixtures_dir / "exclude-whl-include-sdist"
-    builder = Builder(Factory().create_poetry(module_path))
-    builder.build(fmt="all")
+    poetry = Factory().create_poetry(module_path)
+    SdistBuilder(poetry).build()
+    WheelBuilder(poetry).build()
 
     sdist = module_path / "dist" / "exclude_whl_include_sdist-0.1.0.tar.gz"
 
