@@ -116,6 +116,7 @@ def test_convert_dependencies() -> None:
     assert result == (main, extras)
 
 
+@pytest.mark.filterwarnings("ignore:.* script .* extra:DeprecationWarning")
 def test_make_setup() -> None:
     poetry = Factory().create_poetry(project("complete"))
 
@@ -175,23 +176,40 @@ def test_find_files_to_add() -> None:
     poetry = Factory().create_poetry(project("complete"))
 
     builder = SdistBuilder(poetry)
-    result = [f.relative_to_source_root() for f in builder.find_files_to_add()]
+    result = {f.relative_to_source_root() for f in builder.find_files_to_add()}
 
-    assert sorted(result) == sorted(
-        [
-            Path("LICENSE"),
-            Path("README.rst"),
-            Path("bin/script.sh"),
-            Path("my_package/__init__.py"),
-            Path("my_package/data1/test.json"),
-            Path("my_package/sub_pkg1/__init__.py"),
-            Path("my_package/sub_pkg2/__init__.py"),
-            Path("my_package/sub_pkg2/data2/data.json"),
-            Path("my_package/sub_pkg3/foo.py"),
-            Path("pyproject.toml"),
-        ]
+    assert result == {
+        Path("AUTHORS"),
+        Path("COPYING"),
+        Path("LICENCE"),
+        Path("LICENSE"),
+        Path("README.rst"),
+        Path("bin/script.sh"),
+        Path("my_package/__init__.py"),
+        Path("my_package/data1/test.json"),
+        Path("my_package/sub_pkg1/__init__.py"),
+        Path("my_package/sub_pkg2/__init__.py"),
+        Path("my_package/sub_pkg2/data2/data.json"),
+        Path("my_package/sub_pkg3/foo.py"),
+        Path("pyproject.toml"),
+    }
+
+
+def test_find_files_to_add_with_multiple_readme_files() -> None:
+    poetry = Factory().create_poetry(
+        Path(__file__).parent.parent.parent / "fixtures" / "with_readme_files"
     )
 
+    builder = SdistBuilder(poetry)
+    result = {f.relative_to_source_root() for f in builder.find_files_to_add()}
+
+    assert result == {
+        Path("README-1.rst"),
+        Path("README-2.rst"),
+        Path("my_package/__init__.py"),
+        Path("pyproject.toml"),
+    }
+
 
 def test_make_pkg_info_multi_constraints_dependency() -> None:
     poetry = Factory().create_poetry(
@@ -281,12 +299,13 @@ def test_sdist_reproducibility() -> None:
     assert len(hashes) == 1
 
 
+@pytest.mark.filterwarnings("ignore:.* script .* extra:DeprecationWarning")
 def test_setup_py_context() -> None:
     poetry = Factory().create_poetry(project("complete"))
 
     builder = SdistBuilder(poetry)
 
-    project_setup_py = poetry.file.parent / "setup.py"
+    project_setup_py = poetry.pyproject_path.parent / "setup.py"
 
     assert not project_setup_py.exists()
 
@@ -426,21 +445,19 @@ def test_default_with_excluded_data(mocker: MockerFixture) -> None:
     class MockGit:
         def get_ignored_files(self, folder: Path | None = None) -> list[str]:
             # Patch git module to return specific excluded files
-            return [
+            return [(
                 (
-                    (
-                        Path(__file__).parent
-                        / "fixtures"
-                        / "default_with_excluded_data"
-                        / "my_package"
-                        / "data"
-                        / "sub_data"
-                        / "data2.txt"
-                    )
-                    .relative_to(project("default_with_excluded_data"))
-                    .as_posix()
+                    Path(__file__).parent
+                    / "fixtures"
+                    / "default_with_excluded_data"
+                    / "my_package"
+                    / "data"
+                    / "sub_data"
+                    / "data2.txt"
                 )
-            ]
+                .relative_to(project("default_with_excluded_data"))
+                .as_posix()
+            )]
 
     p = mocker.patch("poetry.core.vcs.get_vcs")
     p.return_value = MockGit()
@@ -478,7 +495,6 @@ def test_default_with_excluded_data(mocker: MockerFixture) -> None:
         assert "my_package-1.2.3/my_package/__init__.py" in names
         assert "my_package-1.2.3/my_package/data/data1.txt" in names
         assert "my_package-1.2.3/pyproject.toml" in names
-        assert "my_package-1.2.3/setup.py" in names
         assert "my_package-1.2.3/PKG-INFO" in names
         # all last modified times should be set to a valid timestamp
         for tarinfo in tar.getmembers():
@@ -509,7 +525,6 @@ def test_src_excluded_nested_data() -> None:
         assert "my_package-1.2.3/LICENSE" in names
         assert "my_package-1.2.3/README.rst" in names
         assert "my_package-1.2.3/pyproject.toml" in names
-        assert "my_package-1.2.3/setup.py" in names
         assert "my_package-1.2.3/PKG-INFO" in names
         assert "my_package-1.2.3/my_package/__init__.py" in names
         assert "my_package-1.2.3/my_package/data/sub_data/data2.txt" not in names
