@@ -1,5 +1,9 @@
 from __future__ import annotations
 
+from contextlib import AbstractContextManager
+from contextlib import nullcontext
+from typing import Any
+
 import pytest
 
 from packaging.utils import canonicalize_name
@@ -41,8 +45,7 @@ def test_to_pep_508() -> None:
 
     result = dependency.to_pep_508()
     assert (
-        result
-        == "Django (>=1.23,<2.0) ; "
+        result == "Django (>=1.23,<2.0) ; "
         'python_version >= "2.7" and python_version < "2.8" '
         'or python_version >= "3.6" and python_version < "4.0"'
     )
@@ -57,7 +60,7 @@ def test_to_pep_508_wilcard() -> None:
 
 def test_to_pep_508_in_extras() -> None:
     dependency = Dependency("Django", "^1.23")
-    dependency.in_extras.append(canonicalize_name("foo"))
+    dependency._in_extras = [canonicalize_name("foo")]
 
     result = dependency.to_pep_508()
     assert result == 'Django (>=1.23,<2.0) ; extra == "foo"'
@@ -65,7 +68,7 @@ def test_to_pep_508_in_extras() -> None:
     result = dependency.to_pep_508(with_extras=False)
     assert result == "Django (>=1.23,<2.0)"
 
-    dependency.in_extras.append(canonicalize_name("bar"))
+    dependency._in_extras = [canonicalize_name("foo"), canonicalize_name("bar")]
 
     result = dependency.to_pep_508()
     assert result == 'Django (>=1.23,<2.0) ; extra == "foo" or extra == "bar"'
@@ -74,8 +77,7 @@ def test_to_pep_508_in_extras() -> None:
 
     result = dependency.to_pep_508()
     assert (
-        result
-        == "Django (>=1.23,<2.0) ; "
+        result == "Django (>=1.23,<2.0) ; "
         "("
         'python_version >= "2.7" and python_version < "2.8" '
         'or python_version >= "3.6" and python_version < "4.0"'
@@ -85,8 +87,7 @@ def test_to_pep_508_in_extras() -> None:
 
     result = dependency.to_pep_508(with_extras=False)
     assert (
-        result
-        == "Django (>=1.23,<2.0) ; "
+        result == "Django (>=1.23,<2.0) ; "
         'python_version >= "2.7" and python_version < "2.8" '
         'or python_version >= "3.6" and python_version < "4.0"'
     )
@@ -303,7 +304,8 @@ def test_with_constraint() -> None:
         'python_version >= "3.7" and python_version < "4.0"'
     )
     dependency.python_versions = "^3.6"
-    dependency.transitive_python_versions = "^3.7"
+    with pytest.warns(DeprecationWarning):
+        dependency.transitive_python_versions = "^3.7"
 
     new = dependency.with_constraint("^1.2.6")
 
@@ -316,7 +318,10 @@ def test_with_constraint() -> None:
     assert new.marker == dependency.marker
     assert new.transitive_marker == dependency.transitive_marker
     assert new.python_constraint == dependency.python_constraint
-    assert new.transitive_python_constraint == dependency.transitive_python_constraint
+    with pytest.warns(DeprecationWarning):
+        assert (
+            new.transitive_python_constraint == dependency.transitive_python_constraint
+        )
 
 
 @pytest.mark.parametrize(
@@ -403,7 +408,14 @@ def test_mutable_attributes_not_in_hash(attr_name: str, value: str) -> None:
     dependency = Dependency("foo", "^1.2.3")
     ref_hash = hash(dependency)
 
-    ref_value = getattr(dependency, attr_name)
-    setattr(dependency, attr_name, value)
+    if attr_name == "transitive_python_versions":
+        context: AbstractContextManager[Any] = pytest.warns(DeprecationWarning)
+    else:
+        context = nullcontext()
+
+    with context:
+        ref_value = getattr(dependency, attr_name)
+    with context:
+        setattr(dependency, attr_name, value)
     assert value != ref_value
     assert hash(dependency) == ref_hash
