@@ -9,17 +9,30 @@ from typing import Any
 import pytest
 
 from poetry.core.utils._compat import WINDOWS
+from poetry.core.vcs import get_vcs
 from poetry.core.vcs.git import Git
 from poetry.core.vcs.git import GitError
 from poetry.core.vcs.git import GitUrl
 from poetry.core.vcs.git import ParsedUrl
 from poetry.core.vcs.git import _reset_executable
+from poetry.core.vcs.git import executable
 
 
 if TYPE_CHECKING:
+    from collections.abc import Iterator
+
     from pytest_mock import MockerFixture
 
 
+@pytest.fixture
+def reset_git() -> Iterator[None]:
+    _reset_executable()
+    try:
+        yield
+    finally:
+        _reset_executable()
+
+
 @pytest.mark.parametrize(
     "url, normalized",
     [
@@ -436,16 +449,11 @@ def test_git_rev_parse_raises_error_on_invalid_repository() -> None:
         " reasons"
     ),
 )
-def test_ensure_absolute_path_to_git(mocker: MockerFixture) -> None:
-    _reset_executable()
-
+def test_ensure_absolute_path_to_git(reset_git: None, mocker: MockerFixture) -> None:
     def checkout_output(cmd: list[str], *args: Any, **kwargs: Any) -> str | bytes:
         if Path(cmd[0]).name == "where.exe":
             return "\n".join(
-                [
-                    str(Path.cwd().joinpath("git.exe")),
-                    "C:\\Git\\cmd\\git.exe",
-                ]
+                [str(Path.cwd().joinpath("git.exe")), r"C:\Git\cmd\git.exe"]
             )
 
         return b""
@@ -454,25 +462,21 @@ def test_ensure_absolute_path_to_git(mocker: MockerFixture) -> None:
 
     Git().run("config")
 
-    assert mock.call_args_list[-1][0][0] == [
-        "C:\\Git\\cmd\\git.exe",
-        "config",
-    ]
+    assert mock.call_args_list[-1][0][0] == [r"C:\Git\cmd\git.exe", "config"]
 
-
-@pytest.mark.skipif(
-    not WINDOWS,
-    reason=(
-        "Retrieving the complete path to git is only necessary on Windows, for security"
-        " reasons"
-    ),
-)
-def test_ensure_existing_git_executable_is_found(mocker: MockerFixture) -> None:
     mock = mocker.patch.object(subprocess, "check_output", return_value=b"")
 
     Git().run("config")
 
-    cmd = Path(mock.call_args_list[-1][0][0][0])
+    assert mock.call_args_list[-1][0][0] == [r"C:\Git\cmd\git.exe", "config"]
 
-    assert cmd.is_absolute()
-    assert cmd.name == "git.exe"
+
+def test_get_vcs_encoding(tmp_path: Path) -> None:
+    repo_path = tmp_path / "répö"
+    repo_path.mkdir()
+    assert repo_path.exists()
+    assert subprocess.check_call([executable(), "init"], cwd=repo_path) == 0
+    vcs = get_vcs(repo_path)
+    assert vcs is not None
+    assert vcs._work_dir is not None
+    assert vcs._work_dir.exists()
